[CLEANUP] rename client -> frontend

The 'client.c' file now only contained frontend-specific functions,
so it has naturally be renamed 'frontend.c'. Same for client.h. This
has also been an opportunity to remove some cross references from
files that should not have depended on it.

In the end, this file should contain a protocol-agnostic accept()
code, which would initialize a session, task, etc... based on an
accept() from a lower layer. Right now there are still references
to TCP.
diff --git a/src/backend.c b/src/backend.c
index a1d9c37..0e99879 100644
--- a/src/backend.c
+++ b/src/backend.c
@@ -29,7 +29,7 @@
 
 #include <proto/acl.h>
 #include <proto/backend.h>
-#include <proto/client.h>
+#include <proto/frontend.h>
 #include <proto/lb_chash.h>
 #include <proto/lb_fwlc.h>
 #include <proto/lb_fwrr.h>
diff --git a/src/haproxy.c b/src/haproxy.c
index a2843da..85c2e3a 100644
--- a/src/haproxy.c
+++ b/src/haproxy.c
@@ -72,7 +72,6 @@
 #include <proto/backend.h>
 #include <proto/buffers.h>
 #include <proto/checks.h>
-#include <proto/client.h>
 #include <proto/fd.h>
 #include <proto/log.h>
 #include <proto/protocols.h>
diff --git a/src/proto_http.c b/src/proto_http.c
index 5471ab5..5d8e229 100644
--- a/src/proto_http.c
+++ b/src/proto_http.c
@@ -44,9 +44,9 @@
 #include <proto/backend.h>
 #include <proto/buffers.h>
 #include <proto/checks.h>
-#include <proto/client.h>
 #include <proto/dumpstats.h>
 #include <proto/fd.h>
+#include <proto/frontend.h>
 #include <proto/log.h>
 #include <proto/hdr_idx.h>
 #include <proto/pattern.h>
diff --git a/src/proto_tcp.c b/src/proto_tcp.c
index d336ed1..1662e90 100644
--- a/src/proto_tcp.c
+++ b/src/proto_tcp.c
@@ -39,7 +39,7 @@
 
 #include <proto/acl.h>
 #include <proto/buffers.h>
-#include <proto/client.h>
+#include <proto/frontend.h>
 #include <proto/log.h>
 #include <proto/pattern.h>
 #include <proto/port_range.h>
diff --git a/src/proxy.c b/src/proxy.c
index 7971a7c..155d089 100644
--- a/src/proxy.c
+++ b/src/proxy.c
@@ -27,7 +27,6 @@
 
 #include <types/global.h>
 
-#include <proto/client.h>
 #include <proto/backend.h>
 #include <proto/fd.h>
 #include <proto/hdr_idx.h>
diff --git a/src/stream_interface.c b/src/stream_interface.c
index 871333a..c45abdb 100644
--- a/src/stream_interface.c
+++ b/src/stream_interface.c
@@ -27,7 +27,6 @@
 #include <common/time.h>
 
 #include <proto/buffers.h>
-#include <proto/client.h>
 #include <proto/fd.h>
 #include <proto/stream_interface.h>
 #include <proto/stream_sock.h>
diff --git a/src/stream_sock.c b/src/stream_sock.c
index 8937c2a..d588762 100644
--- a/src/stream_sock.c
+++ b/src/stream_sock.c
@@ -30,7 +30,6 @@
 #include <common/time.h>
 
 #include <proto/buffers.h>
-#include <proto/client.h>
 #include <proto/fd.h>
 #include <proto/pipe.h>
 #include <proto/stream_sock.h>
diff --git a/src/client.c b/src/frontend.c
similarity index 98%
rename from src/client.c
rename to src/frontend.c
index a9bf769..bc354b9 100644
--- a/src/client.c
+++ b/src/frontend.c
@@ -1,7 +1,7 @@
 /*
  * Client-side variables and functions.
  *
- * Copyright 2000-2009 Willy Tarreau <w@1wt.eu>
+ * Copyright 2000-2010 Willy Tarreau <w@1wt.eu>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,8 +28,8 @@
 
 #include <proto/acl.h>
 #include <proto/buffers.h>
-#include <proto/client.h>
 #include <proto/fd.h>
+#include <proto/frontend.h>
 #include <proto/log.h>
 #include <proto/hdr_idx.h>
 #include <proto/proto_tcp.h>
@@ -572,7 +572,7 @@
 
 
 __attribute__((constructor))
-static void __client_init(void)
+static void __frontend_init(void)
 {
 	acl_register_keywords(&acl_kws);
 }
@@ -1,7 +1,7 @@
 /*
- * Client-side variables and functions.
+ * Frontend variables and functions.
  *